@@ -9,7 +9,7 @@ use Digest::SHA();
 use WebService::HIBP::Breach();
 use WebService::HIBP::Paste();
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub _LENGTH_OF_PASSWORD_PREFIX { return 5; }
 
@@ -19,7 +19,7 @@ sub new {
     bless $self, $class;
     $self->{url}          = 'https://haveibeenpwned.com/api/v2/';
     $self->{password_url} = 'https://api.pwnedpasswords.com/range/';
-    $self->{ua}           = LWP::UserAgent->new( agent => 'WebService::HIBP ' );
+    $self->{ua}           = LWP::UserAgent->new( agent => 'WebService-HIBP ' );
     $self->{ua}->env_proxy();
     return $self;
 }
