@@ -44,11 +44,6 @@ sub breach_date {
     return $self->{BreachDate};
 }
 
-sub is_active {
-    my ($self) = @_;
-    return $self->{IsActive};
-}
-
 sub modified_date {
     my ($self) = @_;
     return $self->{ModifiedDate};
@@ -99,9 +94,9 @@ sub data_classes {
     }
 }
 
-sub logo_type {
+sub logo_path {
     my ($self) = @_;
-    return $self->{LogoType};
+    return $self->{LogoPath};
 }
 
 1;    # End of WebService::HIBP::Breach
@@ -193,11 +188,7 @@ Indicates if the breach has been L<retired|https://haveibeenpwned.com/FAQs#Retir
 
 Indicates if the breach is considered a L<spam list|https://haveibeenpwned.com/FAQs#SpamList>. This flag has no impact on any other attributes but it means that the data has not come as a result of a security compromise.
 
-=head2 is_active
-
-No documentation for this yet.  May be removed without notice.
-
-=head2 logo_type
+=head2 logo_path
 
 No documentation for this yet. May be removed without notice.
 
